@@ -45,6 +45,9 @@ PathName::PathName(const PathName& other) : path_(other.path_->clone()) {}
 
 PathName::PathName(const LocalPathName& other) : path_(new BasePathNameT<LocalPathName>(other)) {}
 
+PathName::PathName(const MarsFSPath& other):
+    path_(new BasePathNameT<MarsFSPath>(other)) {
+}
 
 PathName::PathName(BasePathName* path) : path_(path) {
     ASSERT(path);
@@ -103,6 +106,12 @@ time_t PathName::created() const {
     return path_->created();
 }
 
+uid_t PathName::owner() const {
+    struct stat s;
+    SYSCALL(::stat(path_->localPath(), &s));
+    return s.st_uid;
+}
+
 bool PathName::isDir() const {
     return path_->isDir();
 }
